BaseCost
===========================================

.. currentmodule:: skchange.costs

.. autofunction:: BaseCost

.. include:: skchange.costs.BaseCost.examples

.. raw:: html

    <div class="clearer"></div>